@@ -45,7 +45,7 @@ impl LintRule for BanUntaggedTodo {
   }
 
   fn docs(&self) -> &'static str {
-    r#"Requires TODOs to be annotated with either a user tag (@user) or an issue reference (#issue).
+    r#"Requires TODOs to be annotated with either a user tag (`@user`) or an issue reference (`#issue`).
 
 TODOs without reference to a user or an issue become stale with no easy way to get more information.
 
