@@ -51,6 +51,7 @@ removed from the namespace in the future.
 - `Deno.writeAllSync`
 - `Deno.iter`
 - `Deno.iterSync`
+- `Deno.copy`
 
 The IO APIs are already available in `std/io`, so replace these deprecated ones
 with alternatives from `std/io`.
@@ -82,6 +83,9 @@ Deno.writeAllSync(writer, data);
 for await (const x of Deno.iter(xs)) {}
 for (const y of Deno.iterSync(ys)) {}
 
+// copy
+await Deno.copy(reader, writer);
+
 // custom inspector
 class A {
   [Deno.customInspect]() {
@@ -112,6 +116,10 @@ import { iter, iterSync } from "https://deno.land/std/io/util.ts";
 for await (const x of iter(xs)) {}
 for (const y of iterSync(ys)) {}
 
+// copy
+import { copy } from "https://deno.land/std/io/util.ts";
+await copy(reader, writer);
+
 // custom inspector
 class A {
   [Symbol.for("Deno.customInspect")]() {
@@ -155,6 +163,7 @@ enum DeprecatedApi {
   WriteAllSync,
   Iter,
   IterSync,
+  Copy,
   CustomInspect,
 }
 
@@ -180,6 +189,7 @@ impl TryFrom<(&JsWord, &JsWord)> for DeprecatedApi {
       "writeAllSync" => Ok(DeprecatedApi::WriteAllSync),
       "iter" => Ok(DeprecatedApi::Iter),
       "iterSync" => Ok(DeprecatedApi::IterSync),
+      "copy" => Ok(DeprecatedApi::Copy),
       "customInspect" => Ok(DeprecatedApi::CustomInspect),
       _ => Err(()),
     }
@@ -218,6 +228,7 @@ impl DeprecatedApi {
       WriteAllSync => "Deno.writeAllSync",
       Iter => "Deno.iter",
       IterSync => "Deno.iterSync",
+      Copy => "Deno.copy",
       CustomInspect => "Deno.customInspect",
     }
   }
@@ -236,6 +247,7 @@ impl DeprecatedApi {
       WriteAllSync => NameAndUrl("writeAllSync", UTIL_TS),
       Iter => NameAndUrl("iter", UTIL_TS),
       IterSync => NameAndUrl("iterSync", UTIL_TS),
+      Copy => NameAndUrl("copy", UTIL_TS),
       CustomInspect => Name("Symbol.for(\"Deno.customInspect\")"),
     }
   }
@@ -289,6 +301,7 @@ mod tests {
       "Deno.foo.writeAllSync();",
       "Deno.foo.iter();",
       "Deno.foo.iterSync();",
+      "Deno.foo.copy();",
       "Deno.foo.customInspect;",
       "foo.Deno.Buffer();",
       "foo.Deno.readAll();",
@@ -297,6 +310,7 @@ mod tests {
       "foo.Deno.writeAllSync();",
       "foo.Deno.iter();",
       "foo.Deno.iterSync();",
+      "foo.Deno.copy();",
       "foo.Deno.customInspect;",
 
       // `Deno` is shadowed
@@ -307,6 +321,7 @@ mod tests {
       "const Deno = 42; Deno.writeAllSync(writer, data);",
       "const Deno = 42; for await (const x of Deno.iter(xs)) {}",
       "const Deno = 42; for (const x of Deno.iterSync(xs)) {}",
+      "const Deno = 42; await Deno.copy(reader, writer);",
       r#"const Deno = 42; Deno.customInspect"#,
       r#"import { Deno } from "./foo.ts"; Deno.writeAllSync(writer, data);"#,
 
@@ -318,6 +333,7 @@ mod tests {
       r#"const Deno = 42; Deno["writeAllSync"](writer, data);"#,
       r#"const Deno = 42; for await (const x of Deno["iter"](xs)) {}"#,
       r#"const Deno = 42; for (const x of Deno["iterSync"](xs)) {}"#,
+      r#"const Deno = 42; Deno["copy"](reader, writer);"#,
       r#"const Deno = 42; Deno["customInspect"]"#,
 
       // access property with template literal (shadowed)
@@ -328,6 +344,7 @@ mod tests {
       r#"const Deno = 42; Deno[`writeAllSync`](writer, data);"#,
       r#"const Deno = 42; for await (const x of Deno[`iter`](xs)) {}"#,
       r#"const Deno = 42; for (const x of Deno[`iterSync`](xs)) {}"#,
+      r#"const Deno = 42; Deno[`copy`](reader, writer);"#,
       r#"const Deno = 42; Deno[`customInspect`]"#,
 
       // Ignore template literals that include expressions
@@ -390,6 +407,13 @@ mod tests {
           hint: IterSync.hint()
         }
       ],
+      "Deno.copy(reader, writer);": [
+        {
+          col: 0,
+          message: Copy.message(),
+          hint: Copy.hint()
+        }
+      ],
       "Deno.customInspect;": [
         {
           col: 0,
@@ -448,6 +472,13 @@ mod tests {
           hint: IterSync.hint()
         }
       ],
+      r#"Deno["copy"](reader, writer);"#: [
+        {
+          col: 0,
+          message: Copy.message(),
+          hint: Copy.hint()
+        }
+      ],
       r#"Deno["customInspect"];"#: [
         {
           col: 0,
@@ -506,6 +537,13 @@ mod tests {
           hint: IterSync.hint()
         }
       ],
+      r#"Deno[`copy`](reader);"#: [
+        {
+          col: 0,
+          message: Copy.message(),
+          hint: Copy.hint()
+        }
+      ],
       r#"Deno[`customInspect`];"#: [
         {
           col: 0,
